==> php-residence_0.2.4.tar.gz: php-residence/includes/funzioni.php <==
<?php

##################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################



#$pag = explode("/", $SCRIPT_NAME);
#$pag = end($pag);

function mex ($messaggio,$pagina) {

include("dati/lingua.php");
if ($lingua != "ita") {
include("includes/lang/$lingua/$pagina");
} # fine if ($lingua != "ita")

return $messaggio;

} # fine function mex


function controlla_anno ($anno) {

$verificato = "SI";
$verifica_num = ereg_replace("[0-9]","",$anno);
if ($verifica_num != "") $verificato = "NO";
if (strlen($anno) != 4) $verificato = "NO";
$prime_cifre =substr ($anno,0,2);
if ($prime_cifre != 18 and $prime_cifre != 19  and $prime_cifre != 20) $verificato = "NO";

return $verificato;

} # fine function controlla_anno


function controlla_num_pos ($num) {

$verificato = "SI";
$verifica_num = ereg_replace("[0-9]","",$num);
if ($verifica_num != "") $verificato = "NO";

return $verificato;

} # fine function controlla_num_pos


function controlla_num ($num) {

$verificato = "SI";
$uno = substr ($num,0,1);
if ($uno == "-") { $num = substr ($num,1); }
$verifica_num = ereg_replace("[0-9]","",$num);
if ($verifica_num != "") $verificato = "NO";

return $verificato;

} # fine function controlla_num


function nome_valuta () {

$nome_valuta = pg_exec("select * from personalizza where idpersonalizza = 'valuta'");
$nome_valuta = pg_result($nome_valuta,0,valpersonalizza);

return $nome_valuta;

} # fine function nome_valuta


function stile_soldi () {

$stile_soldi = pg_exec("select * from personalizza where idpersonalizza = 'stile_soldi'");
$stile_soldi = pg_result($stile_soldi,0,valpersonalizza);

return $stile_soldi;

} # fine function stile_soldi


function punti_in_num ($num,$stile_soldi="europa") {

#$uno = substr ($num,0,1);
#if ($uno == "-") { $num = substr ($num,1); }
#$num = strrev($num);
#$num = chunk_split($num,3,".");
#$num = substr ($num,0,-1);
#$num = strrev($num);
#if ($uno == "-") { $num = "-".$num; }

if (!strstr($num,".") or substr(strstr($num,"."),1) == 0) $decimali = 0;
else $decimali = 2;
if ($stile_soldi == "usa") $num = number_format($num,$decimali);
else $num = number_format($num,$decimali,",",".");

return $num;

} # fine function punti_in_num


function virgola_in_num ($num,$stile_soldi="europa") {

if ($stile_soldi == "europa") $num = str_replace(".",",",$num);

return $num;

} # fine function virgola_in_num


function controlla_soldi ($num) {

$verificato = "SI";
$uno = substr ($num,0,1);
if ($uno == "-") { $num = substr ($num,1); }
#$num = str_replace(",",".",$num);
$parti = explode(".",$num);
if (count($parti) > 2) $verificato = "NO";
$num = str_replace(".","",$num);
$verifica_num = ereg_replace("[0-9]","",$num);
if ($verifica_num != "") $verificato = "NO";

return $verificato;

} # fine function controlla_soldi


function formatta_soldi ($num) {

$num = str_replace(",",".",$num);
$parti = explode(".",$num);
if (count($parti) == 2) {
if ($parti[1]) {
if (strlen($parti[1]) > 2) {
$parti[1] = substr($parti[1],0,2).".".substr($parti[1],2);
$parti[1] = round($parti[1]);
} # fine if (strlen($parti[1]) > 2)
$num = $parti[0].".".$parti[1];
settype ($num,double);
} # fine if ($parti[1])
else $num = $parti[0];
} # fine if (count($parti) == 2)

return $num;

} # fine function formatta_soldi



?>

==> php-residence_0.3.tar.gz: php-residence/includes/funzioni.php <==
<?php

##################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


# nel caso fosse settato register_globals = Off
if (@is_array($_POST)) reset($_POST);
for($num1 = 0 ; $num1 < count($_POST); $num1++) {
$var_POST = key($_POST);
$$var_POST = $_POST[$var_POST];
next($_POST);
} # fine for $num1
if (@is_array($_GET)) reset($_GET);
for($num1 = 0 ; $num1 < count($_GET); $num1++) {
$var_GET = key($_GET);
$$var_GET = $_GET[$var_GET];
next($_GET);
} # fine for $num1

#$pag = explode("/", $SCRIPT_NAME);
#$pag = end($pag);

function mex ($messaggio,$pagina) {

include("./dati/lingua.php");
if ($lingua != "ita") {
include("./includes/lang/$lingua/$pagina");
} # fine if ($lingua != "ita")

return $messaggio;

} # fine function mex


function controlla_anno ($anno) {

$verificato = "SI";
$verifica_num = ereg_replace("[0-9]","",$anno);
if ($verifica_num != "") $verificato = "NO";
if (strlen($anno) != 4) $verificato = "NO";
$prime_cifre =substr ($anno,0,2);
if ($prime_cifre != 18 and $prime_cifre != 19  and $prime_cifre != 20) $verificato = "NO";

return $verificato;

} # fine function controlla_anno


function controlla_num_pos ($num) {

$verificato = "SI";
if ($num == "") $verificato = "NO";
$verifica_num = ereg_replace("[0-9]","",$num);
if ($verifica_num != "") $verificato = "NO";

return $verificato;

} # fine function controlla_num_pos


function controlla_num ($num) {

$verificato = "SI";
$uno = substr ($num,0,1);
if ($uno == "-") { $num = substr ($num,1); }
$verifica_num = ereg_replace("[0-9]","",$num);
if ($verifica_num != "") $verificato = "NO";

return $verificato;

} # fine function controlla_num


function nome_valuta () {

$nome_valuta = esegui_query("select * from personalizza where idpersonalizza = 'valuta'");
$nome_valuta = risul_query($nome_valuta,0,valpersonalizza);

return $nome_valuta;

} # fine function nome_valuta


function stile_data () {

$stile_data = esegui_query("select * from personalizza where idpersonalizza = 'stile_data'");
$stile_data = risul_query($stile_data,0,valpersonalizza);

return $stile_data;

} # fine function stile_data


function formatta_data ($data,$stile_data="europa") {

$giorno = substr($data,8,2);
$mese = substr($data,5,2);
$anno = substr($data,0,4);
$formato = "d-m-Y";
if ($stile_data == 'usa') $formato = "m-d-Y";
$data_formattata = date ($formato, mktime(0,0,0,$mese,$giorno,$anno));

return $data_formattata;

} # fine function formatta_data


function stile_soldi () {

$stile_soldi = esegui_query("select * from personalizza where idpersonalizza = 'stile_soldi'");
$stile_soldi = risul_query($stile_soldi,0,valpersonalizza);

return $stile_soldi;

} # fine function stile_soldi


function punti_in_num ($num,$stile_soldi="europa") {

#$uno = substr ($num,0,1);
#if ($uno == "-") { $num = substr ($num,1); }
#$num = strrev($num);
#$num = chunk_split($num,3,".");
#$num = substr ($num,0,-1);
#$num = strrev($num);
#if ($uno == "-") { $num = "-".$num; }

if (!strstr($num,".") or substr(strstr($num,"."),1) == 0) $decimali = 0;
else $decimali = 2;
if ($stile_soldi == "usa") $num = number_format($num,$decimali);
else $num = number_format($num,$decimali,",",".");

return $num;

} # fine function punti_in_num


function virgola_in_num ($num,$stile_soldi="europa") {

if ($stile_soldi == "europa") $num = str_replace(".",",",$num);

return $num;

} # fine function virgola_in_num


function controlla_soldi ($num) {

$verificato = "SI";
$uno = substr ($num,0,1);
if ($uno == "-") { $num = substr ($num,1); }
#$num = str_replace(",",".",$num);
$parti = explode(".",$num);
if (count($parti) > 2) $verificato = "NO";
$num = str_replace(".","",$num);
$verifica_num = ereg_replace("[0-9]","",$num);
if ($verifica_num != "") $verificato = "NO";

return $verificato;

} # fine function controlla_soldi


function formatta_soldi ($num) {

$num = str_replace(",",".",$num);
$parti = explode(".",$num);
if (count($parti) == 2) {
if ($parti[1]) {
if (strlen($parti[1]) > 2) {
$parti[1] = substr($parti[1],0,2).".".substr($parti[1],2);
$parti[1] = round($parti[1]);
} # fine if (strlen($parti[1]) > 2)
$num = $parti[0].".".$parti[1];
settype ($num,double);
} # fine if ($parti[1])
else $num = $parti[0];
} # fine if (count($parti) == 2)

return $num;

} # fine function formatta_soldi


function togli_acapo($stringa) {

$stringa = str_replace("\r\n","",$stringa);
$stringa = str_replace("\n","",$stringa);
$stringa = str_replace("
","",$stringa);

return $stringa;

} # fine function togli_acapo



?>
